@@ -87,6 +87,7 @@ class MplCanvas(FigureCanvas):
         # setup Matplotlib Figure and Axis
         self.fig = Figure(facecolor="w")  # 0.75
         self.ax = self.fig.add_subplot(111, zorder=99)
+        self.default_filename = "_image"
 
         # initialization of the canvas
         FigureCanvas.__init__(self, self.fig)
@@ -99,25 +100,32 @@ class MplCanvas(FigureCanvas):
         # notify the system of updated policy
         FigureCanvas.updateGeometry(self)
 
+    def get_default_filename(self):
+        result = self.basename + self.default_filename
+        if len(result) > 100:
+            result = result[:100]
+        return result + ".png"
+
     def drawMetadata(self, title="", init_time=None, valid_time=None,
-                     level=None, style=None, tp=None):
+                     level=None, style=None):
         """Draw a title indicating the init and valid time of the
            image that has been drawn, and the vertical elevation level.
         """
-        if type(style) is str:
+        self.default_filename = ""
+        if title:
+            self.default_filename += "_%5s" % title.split()[0]
+        if isinstance(style, basestring):
             title += ' (%s)' % style
-        if type(level) is str:
+        if isinstance(level, basestring):
             title += ' at %s' % level
-        if type(tp) is str:
-            title += ' with TP at %s' % tp
-
-        if type(valid_time) is datetime and type(init_time) is datetime:
+            self.default_filename += "_%s" % level.split()[0]
+        if isinstance(valid_time, datetime) and isinstance(init_time, datetime):
             time_step = valid_time - init_time
         else:
             time_step = None
-        if type(valid_time) is datetime:
+        if isinstance(valid_time, datetime):
             valid_time = valid_time.strftime('%a %Y-%m-%d %H:%M UTC')
-        if type(init_time) is datetime:
+        if isinstance(init_time, datetime):
             init_time = init_time.strftime('%a %Y-%m-%d %H:%M UTC')
 
         # Add valid time / init time information to the title.
@@ -137,6 +145,8 @@ class MplCanvas(FigureCanvas):
         # Set title.
         self.ax.set_title(title, horizontalalignment='left', x=0)
         self.draw()
+        # without the repaint the title is not properly updated
+        self.repaint()
 
     def getPlotSizePx(self):
         """Determines the size of the current figure in pixels.
@@ -150,9 +160,9 @@ class MplCanvas(FigureCanvas):
         return width, height
 
 
-"""
-Matplotlib Qt Widget
-"""
+#
+# Matplotlib Qt Widget
+#
 
 
 class MplWidget(QtGui.QWidget):
@@ -249,6 +259,7 @@ class MplSideViewCanvas(MplCanvas):
         self.image = None
         # If a waypoints model has been passed, create an interactor on it.
         self.waypoints_interactor = None
+        self.basename = "sideview"
         if model:
             self.setWaypointsModel(model)
 
@@ -541,7 +552,9 @@ class MplTopViewCanvas(MplCanvas):
         super(MplTopViewCanvas, self).__init__()
         self.waypoints_interactor = None
         self.satoverpasspatch = None
+        self.kmloverlay = None
         self.map = None
+        self.basename = "topview"
 
         # Axes and image object to display the legend graphic, if available.
         self.legax = None
@@ -586,11 +599,6 @@ class MplTopViewCanvas(MplCanvas):
                 linecolor=appearance["colour_ft_vertices"],
                 markerfacecolor=appearance["colour_ft_waypoints"])
             self.waypoints_interactor.set_vertices_visible(appearance["draw_flighttrack"])
-            self.waypoints_interactor.set_tangent_visible(appearance["draw_tangents"])
-            self.waypoints_interactor.set_tangent_color(appearance["colour_tangents"])
-            self.waypoints_interactor.set_tangent_height(appearance["tangent_height"])
-            self.waypoints_interactor.set_solar_angle_visible(appearance["show_solar_angle"])
-            self.waypoints_interactor.set_start_time(appearance["start_time"])
 
     def setTrajectoryModel(self, model):
         """
@@ -634,12 +642,11 @@ class MplTopViewCanvas(MplCanvas):
         if self.satoverpasspatch:
             self.satoverpasspatch.update()
 
-        tph = None
-        if self.waypoints_interactor.is_tangent_visible():
-            tph = "{:.1f} km".format(self.waypoints_interactor.get_tangent_height())
-        self.drawMetadata("Top view", tp=tph)
+        if self.kmloverlay:
+            self.kmloverlay.update()
+
+        self.drawMetadata("Top view")
 
-        self.draw()  # without this one the graticule won't plot
         # correctly. no idea why..
         self.waypoints_interactor.update()
 
@@ -763,15 +770,10 @@ class MplTopViewCanvas(MplCanvas):
                     "fill_continents": True,
                     "draw_flighttrack": True,
                     "label_flighttrack": True,
-                    "draw_tangents": False,
-                    "tangent_height": 1.,
-                    "show_solar_angle": False,
                     "colour_water": (153 / 255., 255 / 255., 255 / 255., 255 / 255.),
                     "colour_land": (204 / 255., 153 / 255., 102 / 255., 255 / 255.),
                     "colour_ft_vertices": (0, 0, 1, 1),
-                    "colour_ft_waypoints": (1, 0, 0, 1),
-                    "colour_tangents": (0, 0, 1, 1),
-                    "start_time": datetime.now()}
+                    "colour_ft_waypoints": (1, 0, 0, 1)}
         if settings_dict is not None:
             settings.update(settings_dict)
 
@@ -789,11 +791,13 @@ class MplTopViewCanvas(MplCanvas):
                                                      marker_facecolor=settings["colour_ft_waypoints"])
             self.waypoints_interactor.set_vertices_visible(settings["draw_flighttrack"])
             self.waypoints_interactor.set_labels_visible(settings["label_flighttrack"])
-            self.waypoints_interactor.set_tangent_color(settings["colour_tangents"])
-            self.waypoints_interactor.set_tangent_visible(settings["draw_tangents"])
-            self.waypoints_interactor.set_tangent_height(settings["tangent_height"])
-            self.waypoints_interactor.set_solar_angle_visible(settings["show_solar_angle"])
-            self.waypoints_interactor.set_start_time(settings["start_time"])
+
+    def setRemoteSensingAppearance(self, settings):
+        self.waypoints_interactor.set_remote_sensing(settings["reference"])
+        self.waypoints_interactor.set_tangent_visible(settings["draw_tangents"])
+        self.waypoints_interactor.set_solar_angle_visible(settings["show_solar_angle"])
+
+        self.waypoints_interactor.redraw_path()
 
     def getMapAppearance(self):
         """
@@ -854,6 +858,7 @@ class MplTimeSeriesViewCanvas(MplCanvas):
         if traj_item_tree:
             self.setTrajectoryModel(traj_item_tree)
         self.subPlots = []
+        self.basename = "timeseries"
 
     def setIdentifier(self, identifier):
         self.identifier = identifier
@@ -914,8 +919,8 @@ class MplTimeSeriesViewCanvas(MplCanvas):
         if not self.traj_item_tree:
             return
 
-        logging.debug("updating trajectory items on view <%s>, mode %s" %
-                      (self.identifier, mode))
+        logging.debug("updating trajectory items on view <%s>, mode %s",
+                      self.identifier, mode)
 
         # Determine which items have to be plotted (these are the items that
         # own the variables that will be plotted, not the actual variables
@@ -946,7 +951,7 @@ class MplTimeSeriesViewCanvas(MplCanvas):
                 else:
                     stack.extend(item.childItems)
 
-        logging.debug("Plotting elements %s" % [i.getName() for i in itemsList])
+        logging.debug("Plotting elements %s", [i.getName() for i in itemsList])
 
         if mode in ["REDRAW", "MARKER_CHANGE"]:
             # Clear the figure -- it needs to be completely redrawn.
@@ -967,7 +972,7 @@ class MplTimeSeriesViewCanvas(MplCanvas):
         # Iterative list traversal no. 2: Draw / update plots.
         for item in itemsList:
 
-            logging.debug("plotting item %s" % item.getName())
+            logging.debug("plotting item %s", item.getName())
             # The variables that have to be plotted are children of self.mapItem.
             # Plot all variables whose visible-flag is set to True.
             variablesToPlot = [variable for variable in item.childItems
