@@ -31,13 +31,10 @@ AUTHORS:
 """
 
 # standard library imports
-import datetime
-
 import functools
 import logging
 import os
 import pickle
-import tempfile
 from mslib.mss_util import config_loader
 from mslib.msui import MissionSupportSystemDefaultConfig as mss_default
 # related third party imports
@@ -51,15 +48,19 @@ from mslib.msui import mpl_pathinteractor as mpl_pi
 from mslib.msui import flighttrack as ft
 from mslib.msui import wms_control as wms
 from mslib.msui import satellite_dockwidget as sat
-from mslib.msui import wms_login_cache
+from mslib.msui import remotesensing_dockwidget as rs
+from mslib.msui import kmloverlay_dockwidget as kml
+from mslib.msui import constants
 
 # Dock window indices.
 WMS = 0
 SATELLITE = 1
+REMOTESENSING = 2
+KMLOVERLAY = 3
 
-"""
-DIALOG for map appearance
-"""
+#
+# DIALOG for map appearance
+#
 
 
 class MSS_TV_MapAppearanceDialog(QtGui.QDialog, ui_ma.Ui_MapAppearanceDialog):
@@ -82,24 +83,10 @@ class MSS_TV_MapAppearanceDialog(QtGui.QDialog, ui_ma.Ui_MapAppearanceDialog):
                              "fill_continents": True,
                              "draw_flighttrack": True,
                              "label_flighttrack": True,
-                             "draw_tangents": False,
-                             "show_solar_angle": False,
                              "colour_water": (0, 0, 0, 0),
                              "colour_land": (0, 0, 0, 0),
                              "colour_ft_vertices": (0, 0, 0, 0),
-                             "colour_ft_waypoints": (0, 0, 0, 0),
-                             "colour_tangents": (0, 0, 0, 0)}
-
-        if "draw_tangents" not in settings_dict.keys():
-            settings_dict["draw_tangents"] = False
-        if "tangent_height" not in settings_dict.keys():
-            settings_dict["tangent_height"] = 1.
-        if "show_solar_angle" not in settings_dict.keys():
-            settings_dict["show_solar_angle"] = False
-        if "start_time" not in settings_dict.keys():
-            settings_dict["start_time"] = datetime.datetime.now()
-        if "colour_tangents" not in settings_dict.keys():
-            settings_dict["colour_tangents"] = (0, 0, 0, 0)
+                             "colour_ft_waypoints": (0, 0, 0, 0)}
 
         self.cbDrawGraticule.setChecked(settings_dict["draw_graticule"])
         self.cbDrawCoastlines.setChecked(settings_dict["draw_coastlines"])
@@ -107,16 +94,11 @@ class MSS_TV_MapAppearanceDialog(QtGui.QDialog, ui_ma.Ui_MapAppearanceDialog):
         self.cbFillContinents.setChecked(settings_dict["fill_continents"])
         self.cbDrawFlightTrack.setChecked(settings_dict["draw_flighttrack"])
         self.cbLabelFlightTrack.setChecked(settings_dict["label_flighttrack"])
-        self.cbDrawTangents.setChecked(settings_dict["draw_tangents"])
-        self.dsbTangentHeight.setValue(settings_dict["tangent_height"])
-        self.cbShowSolarAngle.setChecked(settings_dict["show_solar_angle"])
-        self.dteStartTime.setDateTime(settings_dict["start_time"])
 
         for button, ids in [(self.btWaterColour, "colour_water"),
                             (self.btLandColour, "colour_land"),
                             (self.btWaypointsColour, "colour_ft_waypoints"),
-                            (self.btVerticesColour, "colour_ft_vertices"),
-                            (self.btTangentsColour, "colour_tangents")]:
+                            (self.btVerticesColour, "colour_ft_vertices")]:
             palette = QtGui.QPalette(button.palette())
             colour = QtGui.QColor()
             colour.setRgbF(*settings_dict[ids])
@@ -132,8 +114,6 @@ class MSS_TV_MapAppearanceDialog(QtGui.QDialog, ui_ma.Ui_MapAppearanceDialog):
                      functools.partial(self.setColour, "ft_waypoints"))
         self.connect(self.btVerticesColour, QtCore.SIGNAL("clicked()"),
                      functools.partial(self.setColour, "ft_vertices"))
-        self.connect(self.btTangentsColour, QtCore.SIGNAL("clicked()"),
-                     functools.partial(self.setColour, "tangents"))
 
     def getSettings(self):
         """
@@ -145,10 +125,6 @@ class MSS_TV_MapAppearanceDialog(QtGui.QDialog, ui_ma.Ui_MapAppearanceDialog):
             "fill_continents": self.cbFillContinents.isChecked(),
             "draw_flighttrack": self.cbDrawFlightTrack.isChecked(),
             "label_flighttrack": self.cbLabelFlightTrack.isChecked(),
-            "draw_tangents": self.cbDrawTangents.isChecked(),
-            "tangent_height": self.dsbTangentHeight.value(),
-            "show_solar_angle": self.cbShowSolarAngle.isChecked(),
-            "start_time": self.dteStartTime.dateTime().toPyDateTime(),
 
             "colour_water":
                 QtGui.QPalette(self.btWaterColour.palette()).color(QtGui.QPalette.Button).getRgbF(),
@@ -158,8 +134,6 @@ class MSS_TV_MapAppearanceDialog(QtGui.QDialog, ui_ma.Ui_MapAppearanceDialog):
                 QtGui.QPalette(self.btVerticesColour.palette()).color(QtGui.QPalette.Button).getRgbF(),
             "colour_ft_waypoints":
                 QtGui.QPalette(self.btWaypointsColour.palette()).color(QtGui.QPalette.Button).getRgbF(),
-            "colour_tangents":
-                QtGui.QPalette(self.btTangentsColour.palette()).color(QtGui.QPalette.Button).getRgbF()
         }
         return settings_dict
 
@@ -175,8 +149,6 @@ class MSS_TV_MapAppearanceDialog(QtGui.QDialog, ui_ma.Ui_MapAppearanceDialog):
             button = self.btVerticesColour
         elif which == "ft_waypoints":
             button = self.btWaypointsColour
-        elif which == "tangents":
-            button = self.btTangentsColour
 
         palette = QtGui.QPalette(button.palette())
         colour = palette.color(QtGui.QPalette.Button)
@@ -186,9 +158,9 @@ class MSS_TV_MapAppearanceDialog(QtGui.QDialog, ui_ma.Ui_MapAppearanceDialog):
             button.setPalette(palette)
 
 
-"""
-CLASS FlightPlanTopView
-"""
+#
+# CLASS FlightPlanTopView
+#
 
 
 class MSSTopViewWindow(mss_qt.MSSMplViewWindow, ui.Ui_TopViewWindow):
@@ -203,10 +175,10 @@ class MSSTopViewWindow(mss_qt.MSSMplViewWindow, ui.Ui_TopViewWindow):
         super(MSSTopViewWindow, self).__init__(parent, model)
         self.setupUi(self)
 
-        # Dock windows [WMS, Satellite, Trajectories]:
-        self.docks = [None, None, None]
+        # Dock windows [WMS, Satellite, Trajectories, Remote Sensing, KML Overlay]:
+        self.docks = [None, None, None, None, None]
 
-        self.settingsfile = os.path.join(wms_login_cache.DEFAULT_CONFIG_PATH, "mss.topview.cfg")
+        self.settingsfile = os.path.join(constants.MSS_CONFIG_PATH, "mss.topview.cfg")
         self.loadSettings()
 
         # Initialise the GUI elements (map view, items of combo boxes etc.).
@@ -241,11 +213,14 @@ class MSSTopViewWindow(mss_qt.MSSMplViewWindow, ui.Ui_TopViewWindow):
         self.connect(self.btDelWaypoint, QtCore.SIGNAL("clicked()"),
                      functools.partial(wpi.set_edit_mode, mpl_pi.DELETE))
 
+    def __del__(self):
+        del self.mpl.canvas.waypoints_interactor
+
     def setupTopView(self):
         """Initialise GUI elements. (This method is called before signals/slots
            are connected).
         """
-        toolitems = ["(select to open control)", "Web Map Service", "Satellite Tracks"]
+        toolitems = ["(select to open control)", "Web Map Service", "Satellite Tracks", "Remote Sensing", "KML Overlay"]
         self.cbTools.clear()
         self.cbTools.addItems(toolitems)
 
@@ -276,12 +251,15 @@ class MSSTopViewWindow(mss_qt.MSSMplViewWindow, ui.Ui_TopViewWindow):
                     view=self.mpl.canvas,
                     wms_cache=config_loader(dataset="wms_cache",
                                             default=mss_default.wms_cache))
-                settings = self.getView().getMapAppearance()
-                if settings["draw_tangents"]:
-                    widget.set_tp_height(settings["tangent_height"])
             elif index == SATELLITE:
                 title = "Satellite Track Prediction"
                 widget = sat.SatelliteControlWidget(view=self.mpl.canvas)
+            elif index == REMOTESENSING:
+                title = "Remote Sensing Tools"
+                widget = rs.RemoteSensingControlWidget(view=self.mpl.canvas)
+            elif index == KMLOVERLAY:
+                title = "KML Overlay"
+                widget = kml.KMLOverlayControlWidget(view=self.mpl.canvas)
             else:
                 raise IndexError("invalid control index")
 
@@ -327,14 +305,6 @@ class MSSTopViewWindow(mss_qt.MSSMplViewWindow, ui.Ui_TopViewWindow):
             settings = dlg.getSettings()
             self.getView().setMapAppearance(settings)
             self.saveSettings()
-            if self.docks[WMS]:
-                if settings["draw_tangents"]:
-                    self.docks[WMS].widget().set_tp_height(settings["tangent_height"])
-                else:
-                    self.docks[WMS].widget().set_tp_height(None)
-            tph = None
-            if settings["draw_tangents"]:
-                tph = "{:.1f} km".format(settings["tangent_height"])
             if self.docks[WMS]:
                 wms_widget = self.docks[WMS].widget()
                 layer = wms_widget.getLayer()
@@ -350,10 +320,9 @@ class MSSTopViewWindow(mss_qt.MSSMplViewWindow, ui.Ui_TopViewWindow):
                                              init_time=init_time,
                                              valid_time=valid_time,
                                              level=level,
-                                             style=style_title,
-                                             tp=tph)
+                                             style=style_title)
             else:
-                self.mpl.canvas.drawMetadata(title="Top view", tp=tph)
+                self.mpl.canvas.drawMetadata(title="Top view")
             self.mpl.canvas.waypoints_interactor.redraw_path()
         dlg.destroy()
 
@@ -364,7 +333,7 @@ class MSSTopViewWindow(mss_qt.MSSMplViewWindow, ui.Ui_TopViewWindow):
         # TODO: ConfigParser and a central configuration file might be the better solution than pickle.
         # http://stackoverflow.com/questions/200599/whats-the-best-way-to-store-simple-user-settings-in-python
         settings = self.getView().getMapAppearance()
-        logging.debug("storing settings to %s" % self.settingsfile)
+        logging.debug("storing settings to %s", self.settingsfile)
         fileobj = open(self.settingsfile, "w")
         pickle.dump(settings, fileobj)
         fileobj.close()
@@ -374,7 +343,7 @@ class MSSTopViewWindow(mss_qt.MSSMplViewWindow, ui.Ui_TopViewWindow):
         """
         settings = None
         if os.path.exists(self.settingsfile):
-            logging.debug("loading settings from %s" % self.settingsfile)
+            logging.debug("loading settings from %s", self.settingsfile)
             fileobj = open(self.settingsfile, "r")
             settings = pickle.load(fileobj)
             fileobj.close()
@@ -385,7 +354,7 @@ class MSSTopViewWindow(mss_qt.MSSMplViewWindow, ui.Ui_TopViewWindow):
 # will not be executed if the view is opened from the Mission Support
 # System user interface.
 
-if __name__ == "__main__":
+def _main():
     # Log everything, and send it to stderr.
     # See http://docs.python.org/library/logging.html for more information
     # on the Python logging module.
@@ -408,7 +377,10 @@ if __name__ == "__main__":
     waypoints_model.insertRows(0, rows=len(initial_waypoints),
                                waypoints=initial_waypoints)
 
-    app = QtGui.QApplication(sys.argv)
-    win = MSSTopViewWindow(model=waypoints_model)
-    win.show()
-    sys.exit(app.exec_())
+    application = QtGui.QApplication(sys.argv)
+    window = MSSTopViewWindow(model=waypoints_model)
+    window.show()
+    sys.exit(application.exec_())
+
+if __name__ == "__main__":
+    _main()
